#
# spec file for package gitui
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gitui
Version:        0.24.3
Release:        1.3
Summary:        Terminal UI for git
License:        (Apache-2.0 OR MIT) AND Unicode-DFS-2016 AND (0BSD OR MIT OR Apache-2.0) AND (Apache-2.0 OR BSL-1.0) AND (Apache-2.0 OR MIT) AND (Apache-2.0 OR Apache-2.0 WITH LLVM-exception OR MIT) AND (Artistic-2.0 OR CC0-1.0) AND (Apache-2.0 OR MIT OR Zlib) AND (Apache-2.0 OR MIT OR Zlib) AND (MIT OR Unlicense) AND (Apache-2.0 OR Zlib OR MIT) AND Apache-2.0 AND BSD-2-Clause AND BSD-3-Clause AND CDDL-1.0 AND ISC AND MIT AND MIT AND CC-BY-3.0 AND MPL-2.0 AND SUSE-GPL-2.0-with-linking-exception
URL:            https://github.com/extrawurst/gitui
Source0:        https://github.com/extrawurst/gitui/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  cargo-packaging
BuildRequires:  rust+cargo
BuildRequires:  zstd
BuildRequires:  pkgconfig(libgit2)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(zlib)

%description
TUI for git with the following features:
  * Fast and intuitive keyboard only control
  * Context based help (no need to memorize tons of hot-keys)
  * Inspect, commit, and amend changes (incl. hooks: pre-commit,commit-msg,post-commit)
  * Stage, unstage, revert and reset files, hunks and lines
  * Stashing (save, pop, apply, drop, and inspect)
  * Push/Fetch to/from remote
  * Branch List (create, rename, delete, checkout, remotes)
  * Browse commit log, diff committed changes
  * Scalable terminal UI layout
  * Async git API for fluid control
  * Submodule support

%prep
%setup -qa1
mkdir -p .cargo
cp %{SOURCE2} .cargo/config

%build
%cargo_build

%install
%cargo_install

%check
%cargo_test

%files
%license LICENSE.md
%doc CHANGELOG.md README.md FAQ.md THEMES.md
%{_bindir}/%{name}

%changelog
* Tue Sep 19 2023 Lubos Kocman <lubos.kocman@suse.com>
- Update license based on legaldb review
* Sat Sep  9 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.24.3:
  * log: fix major lag when going beyond last search hit
  * parallelise log search - performance gain ~100%%
  * search message body/summary separately
  * fix commit log not updating after branch switch
  * fix stashlist not updating after pop/drop
  * fix commit log corruption when tabbing in/out while parsing log
  * fix performance problem in big repo with a lot of incoming commits
  * fix error switching to a branch with '/' in the name
  * search commits by message, author or files in diff
  * support 'n'/'p' key to move to the next/prev hunk in diff component
  * simplify theme overrides
  * support for sign-off of commits
  * switched from textwrap to bwrap for text wrapping
  * more logging diagnostics when a repo cannot be
  * added to anaconda
  * visualize empty line substituted with content in diff better
  * checkout branch works with non-empty status report
  * jump to commit by SHA
  * fix commit dialog char count for multibyte characters
  * fix wrong hit highlighting in fuzzy find popup
  * fix symlink support for configuration files
  * fix expansion of ~ in commit.template
  * fix hunk (un)staging/reset for # of context lines != 3
  * fix delay when opening external editor
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Fri Jun 23 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.23.0
  - Breaking Change
  * focus_XYZ key bindings are merged into the move_XYZ set, so only one way to bind arrow-like keys from now on
  - Added
  * allow reset (soft,mixed,hard) from commit log
  * support reword of commit from log
  * fuzzy find branch
  * list changes in commit message inside external editor
  * allow detaching HEAD and checking out specific commit from log view
  * add no-verify option on commits to not run hooks
  * allow fetch on status tab
  * allow copy file path on revision files and status tree
  * print message of where log will be written if -l is set
  * show remote branches in log
  - Fixes
  * fixed side effect of crossterm 0.26 on windows that caused double input of all keys
  * commit msg history ordered the wrong way
  * improve help documentation for amend cmd
  * lag issue when showing files tab
  * fix key binding shown in bottom bar for stash_open
  * --bugreport does not require param
  * edit-file command shown on commits msg
  * crash on branches popup in small terminal
  * edit command duplication
  * syntax errors in key_bindings.ron will be logged
  * Fix UI freeze when copying with xclip installed on Linux
  * Fix UI freeze when copying with wl-copy installed on Linux
  * commit hooks report "command not found" on Windows with wsl2 installed
  * crashes on entering submodules
  * fix race issue: revlog messages sometimes appear empty
  * default to tick-based updates
  * add support for options handling in log and stashes views
  - Changed
  * minimum supported rust version bumped to 1.65 (thank you time crate)
* Sat Mar 11 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Set worker disk size to 4GB to fix "No space left on device" on pp64.
* Sat Mar 11 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update vendored dependencies
- Use zstd compression for tarballs.
* Sat Mar 11 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Remove gitui-v0.22.1.obscpio file. Forgot to delete
* Fri Jan  6 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix version name both on specfile and tarball sources.
* Wed Jan  4 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for gitui 0.22.1
